'This example uses the Add method to create a rib feature.  To try this example you must have an 'existing part like that shown in the figure.  It is a box that is open on the top and is approx. '4 inches (10 cm) square.  The box is approx. centered about the base reference planes.  Solid 'Edge should be running and the box model active.  To run the sample, paste the code into the 'General section of a form.  Then press F5 and click the form.

Private Sub Form_Click()
    Dim objApp As Object
    Dim dblOrigin(1 To 2) As Double
    Dim lngStatus As Long
    Dim objProfile As Object


    ' Connect to a running instance of Solid Edge
    Set objApp = GetObject(, "SolidEdge.Application")

    ' Create the Profile object using the xz reference plane,
    ' which is the third one in the reference planes collection.
    Set objProfile = objApp.ActiveDocument.ProfileSets.Add.Profiles.Add( _
                        pRefPlaneDisp:=objApp.ActiveDocument.RefPlanes(3))

   
    ' Get the reference plane coordinate that corresponds with
    ' the model origin coordinate.
    Call objProfile.Convert3DCoordinate(x3d:=0, y3d:=0, z3d:=0, _
                                        x2d:=dblOrigin(1), y2d:=dblOrigin(2))
    
    ' Place a line that defines the top of the rib.
    Call objProfile.Lines2d.AddBy2Points(X1:=dblOrigin(1), Y1:=dblOrigin(2), _
                            X2:=dblOrigin(1) + 0.01, Y2:=dblOrigin(2))
    
    ' Complete the profile, verifying it is valid.

    lngStatus = objProfile.End(nValidationCriteria:=igProfileSingle)
    If lngStatus <> 0 Then
        MsgBox "Invalid profile defined."
        End
    End If
    
    ' Turn off the display of the profile.
     objProfile.Visible = False
    
    ' Place the rib feature.
    Call objApp.ActiveDocument.Models(1).Ribs.Add( _
            RibProfile:=objProfile, _
            ProfileExtensionType:=igExtend, _
            ThicknessType:=igThkNormalToProfilePlane, _

            MaterialSide:=igRight, ThicknessSide:=igSymmetric, _
            Thickness:=0.02, FiniteDepth:=0.01)
End Sub